#[non_exhaustive]pub enum KeyMaterialKind {
NotKey,
PublicKey,
PrivateKey,
SymmetricKey,
}Expand description
Key-material class for codecs that carry raw key bytes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotKey
The codec is not raw key material.
PublicKey
Public key material that is safe for multikey verification methods.
PrivateKey
Private key material. The codec is known, but multikey must reject it.
SymmetricKey
Symmetric key material. The codec is known, but multikey must reject it.